@@ -1,36 +1,28 @@
 """
 
-ro.py > assets.py
-
 This file houses functions and classes that pertain to Roblox assets.
 
 """
-
-from ro_py.users import User
-from ro_py.groups import Group
 from ro_py.utilities.errors import NotLimitedError
+from ro_py.economy import LimitedResaleData
 from ro_py.utilities.asset_type import asset_types
 import iso8601
 
 endpoint = "https://api.roblox.com/"
 
 
-class LimitedResaleData:
-    """
-    Represents the resale data of a limited item.
-    """
-    def __init__(self, resale_data):
-        self.asset_stock = resale_data["assetStock"]
-        self.sales = resale_data["sales"]
-        self.number_remaining = resale_data["numberRemaining"]
-        self.recent_average_price = resale_data["recentAveragePrice"]
-        self.original_price = resale_data["originalPrice"]
-
-
 class Asset:
     """
     Represents an asset.
+
+    Parameters
+    ----------
+    requests : ro_py.utilities.requests.Requests
+        Requests object to use for API requests.
+    asset_id
+        ID of the asset.
     """
+
     def __init__(self, requests, asset_id):
         self.id = asset_id
         self.requests = requests
@@ -53,13 +45,12 @@ class Asset:
         self.is_limited_unique = None
         self.minimum_membership_level = None
         self.content_rating_type_id = None
-        self.update()
 
-    def update(self):
+    async def update(self):
         """
         Updates the asset's information.
         """
-        asset_info_req = self.requests.get(
+        asset_info_req = await self.requests.get(
             url=endpoint + "marketplace/productinfo",
             params={
                 "assetId": self.id
@@ -74,10 +65,10 @@ class Asset:
         self.description = asset_info["Description"]
         self.asset_type_id = asset_info["AssetTypeId"]
         self.asset_type_name = asset_types[self.asset_type_id]
-        if asset_info["Creator"]["CreatorType"] == "User":
-            self.creator = User(self.requests, asset_info["Creator"]["Id"])
-        elif asset_info["Creator"]["CreatorType"] == "Group":
-            self.creator = Group(self.requests, asset_info["Creator"]["CreatorTargetId"])
+        # if asset_info["Creator"]["CreatorType"] == "User":
+        #    self.creator = User(self.requests, asset_info["Creator"]["Id"])
+        # if asset_info["Creator"]["CreatorType"] == "Group":
+        #    self.creator = Group(self.requests, asset_info["Creator"]["CreatorTargetId"])
         self.created = iso8601.parse_date(asset_info["Created"])
         self.updated = iso8601.parse_date(asset_info["Updated"])
         self.price = asset_info["PriceInRobux"]
@@ -89,12 +80,15 @@ class Asset:
         self.minimum_membership_level = asset_info["MinimumMembershipLevel"]
         self.content_rating_type_id = asset_info["ContentRatingTypeId"]
 
-    def get_remaining(self):
+    async def get_remaining(self):
         """
         Gets the remaining amount of this asset. (used for Limited U items)
-        :returns: Amount remaining
+
+        Returns
+        -------
+        int
         """
-        asset_info_req = self.requests.get(
+        asset_info_req = await self.requests.get(
             url=endpoint + "marketplace/productinfo",
             params={
                 "assetId": self.asset_id
@@ -103,13 +97,23 @@ class Asset:
         asset_info = asset_info_req.json()
         return asset_info["Remaining"]
 
-    def get_limited_resale_data(self):
+    async def get_limited_resale_data(self):
         """
         Gets the limited resale data
-        :returns: LimitedResaleData
+
+        Returns
+        -------
+        LimitedResaleData
         """
         if self.is_limited:
-            resale_data_req = self.requests.get(f"https://economy.roblox.com/v1/assets/{self.asset_id}/resale-data")
+            resale_data_req = await self.requests.get(
+                f"https://economy.roblox.com/v1/assets/{self.asset_id}/resale-data")
             return LimitedResaleData(resale_data_req.json())
         else:
             raise NotLimitedError("You can only read this information on limited items.")
+
+
+class UserAsset(Asset):
+    def __init__(self, requests, asset_id, user_asset_id):
+        super().__init__(requests, asset_id)
+        self.user_asset_id = user_asset_id
