@@ -45,3 +45,22 @@ class UserDoesNotExistError(Exception):
 
 class GameJoinError(Exception):
     """Called when an error occurs when joining a game."""
+
+
+class InvalidPlaceIDError(Exception):
+    """Called when place ID is invalid."""
+
+
+class IncorrectKeyError(Exception):
+    """Raised when the api key for 2captcha is incorrect."""
+    pass
+
+
+class InsufficientCreditError(Exception):
+    """Raised when there is insufficient credit in 2captcha."""
+    pass
+
+
+class NoAvailableWorkersError(Exception):
+    """Raised when there are no available workers."""
+    pass
